# Generated by Django 2.2.1 on 2019-05-27 10:39

from django.db import migrations, models

import mailauth


class Migration(migrations.Migration):

    dependencies = [
        ("mailauth_user", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="emailuser",
            name="session_salt",
            field=models.CharField(
                default=mailauth.contrib.user.models._get_session_salt,
                editable=False,
                max_length=12,
            ),
        ),
    ]
